@@ -118,20 +118,22 @@ def set_context(ctx, config):
     config_dict = settings_dict['configs'][config]
     provider_data = config_dict.get('cloud_provider')
 
-    if settings_dict.get('version') == '1' or settings_dict.get('version') == 1:
-        ctx.run('kubectl config use-context gcp_{cloud_project}_{cluster}_europe-west1-c'
-            ' --namespace={namespace}'
-            .format(namespace=config_dict['namespace'],
-                    cloud_project=config_dict['cloud_project'],
-                    cluster=config_dict['cluster']),
-            echo=True)
-        ctx.run('kubectl config set-context --current'
-            ' --namespace={namespace}'
-            .format(namespace=config_dict['namespace']),
-            echo=True)
+    # Check for future versions
+    if settings_dict.get('version') and version.parse(str(settings_dict['version'])) > version.parse('3'):
+        sys.exit(f"Unsupported rdeploy.yaml version, please upgrade rdeploy or double check the version number.")
+
+    # v3 of the config file uses the kube_context value to set the kubernetes cluster context
+    # whereas previous versions used the GCP/AZ tools to set it and a naming convention        
+    elif str(settings_dict.get('version')) == '3':
+        ctx.run('kubectl config use-context {kube_context}'
+                    .format(kube_context = config_dict['kube_context']),
+                    echo=True)
+        ctx.run('kubectl config set-context --current --namespace={namespace}'
+                    .format(namespace=config_dict['namespace']),
+                    echo=True)
 
 
-    elif settings_dict.get('version') == '2' or settings_dict.get('version') == 2:
+    elif str(settings_dict.get('version')) == '2':
         if provider_data.get('name') == 'gcp':
             if provider_data.get('zone') is not None:
                 get_zone = provider_data['zone']
@@ -165,9 +167,20 @@ def set_context(ctx, config):
                 echo=True)
         else:
             sys.exit(f"Invalid provider name in rdeploy file: {provider_data.get('name')}")
-    else:
-        sys.exit(f"Invalid rdeploy version in rdeploy file: {settings_dict.get('version')}")
 
+    # Config file v1 or no version
+    # Backwards compatible with initial version of rdeploy where config file was not yet versioned.
+    else:
+        ctx.run('kubectl config use-context gcp_{cloud_project}_{cluster}_europe-west1-c'
+            ' --namespace={namespace}'
+            .format(namespace=config_dict['namespace'],
+                    cloud_project=config_dict['cloud_project'],
+                    cluster=config_dict['cluster']),
+            echo=True)
+        ctx.run('kubectl config set-context --current'
+            ' --namespace={namespace}'
+            .format(namespace=config_dict['namespace']),
+            echo=True)
 
 # Versioning Helpers
 ####################
@@ -559,24 +572,33 @@ def cloudbuild(ctx, config, tag):
     """
     settings_dict = get_settings()
     config_dict = settings_dict['configs'][config]
-    set_project(ctx, config)
     image_name = config_dict['docker_image'].split(':')[0]
 
+    if config_dict.get('container_registry_provider') == 'google':
+        project = config_dict['docker_image'].split('/')[1]
+        ctx.run('gcloud config set project {project}'
+            .format(project=project), echo=True)
+    else:
+        set_project(ctx, config)
+
+
     if settings_dict.get('version') and version.parse(str(settings_dict['version'])) > version.parse('1'):
         provider_data = config_dict.get('cloud_provider')
-        if provider_data and provider_data['name'] == 'azure':
+
+        def azure_image_build(container_registry, image_name, tag):
             ctx.run('az acr run'
                 ' -r {container_registry}'
                 ' -f ./etc/docker/acr.yaml'
                 ' --set IMAGE={image_name}'
                 ' --set TAG_NAME={tag_name}'
                 ' .'
-                .format(container_registry=provider_data['container_registry'],
+                .format(container_registry=container_registry,
                         image_name=image_name,
                         tag_name=tag), echo=True)
-        else:
+
+        def google_image_build(project, image_name, tag):
             log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
-            project=provider_data['project'], image=image_name, tag_name=tag)
+            project=project, image=image_name, tag_name=tag)
             ctx.run('gcloud builds submit .'
                 ' --config etc/docker/cloudbuild.yaml'
                 ' --substitutions _IMAGE={image_name},TAG_NAME={tag_name}'
@@ -584,49 +606,18 @@ def cloudbuild(ctx, config, tag):
                 .format(image_name=image_name, tag_name=tag, log_dir=log_dir),
                 echo=True)
 
+        if config_dict.get('container_registry_provider') == 'azure':
+            azure_image_build(provider_data['container_registry'], image_name, tag)
 
-    else:
-        log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
-        project=config_dict['cloud_project'], image=image_name, tag_name=tag)
-        ctx.run('gcloud builds submit .'
-            ' --config etc/docker/cloudbuild.yaml'
-            ' --substitutions _IMAGE={image_name},TAG_NAME={tag_name}'
-            ' --gcs-log-dir {log_dir}'
-            .format(image_name=image_name, tag_name=tag, log_dir=log_dir),
-            echo=True)
+        elif config_dict.get('container_registry_provider') == 'google':
+            project = config_dict['docker_image'].split('/')[1]
+            google_image_build(project, image_name, tag)
 
-
-@task(aliases=['cloudbuild-initial'])
-def cloudbuild_initial(ctx, config, tag):
-    """
-    Build project's docker image using google cloud builder and pushes to remote repo
-    """
-    settings_dict = get_settings()
-    config_dict = settings_dict['configs'][config]
-    set_project(ctx, config)
-    image_name = config_dict['docker_image'].split(':')[0]
-
-    if settings_dict.get('version') and version.parse(str(settings_dict['version'])) > version.parse('1'):
-        provider_data = config_dict.get('cloud_provider')
-        if provider_data and provider_data['name'] == 'azure':
-            ctx.run('az acr run'
-                ' -r {container_registry}'
-                ' -f ./etc/docker/acr-no-cache.yaml'
-                ' --set IMAGE={image_name}'
-                ' --set TAG_NAME={tag_name}'
-                ' .'
-                .format(container_registry=provider_data['container_registry'],
-                        image_name=image_name,
-                        tag_name=tag), echo=True)
         else:
-            log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
-            project=provider_data['project'], image=image_name, tag_name=tag)
-            ctx.run('gcloud builds submit .'
-                    ' --config etc/docker/cloudbuild-no-cache.yaml'
-                    ' --substitutions _IMAGE={image_name},TAG_NAME={tag_name}'
-                    ' --gcs-log-dir {log_dir}'
-                    .format(image_name=image_name, tag_name=tag, log_dir=log_dir),
-                    echo=True)
+            if provider_data and provider_data['name'] == 'azure':
+                azure_image_build(provider_data['container_registry'], image_name, tag)
+            else:
+                google_image_build(provider_data['project'], image_name, tag)
 
     else:
         log_dir = "gs://{project}-cloudbuild-logs/{image}/{tag_name}/".format(
